require "random_us_city/version"
require "csv"


=begin rdoc
   This class returns a struct with data for a random city in the US.

   For example:

     #<struct RandomUsCity::City
      zip="67878",
      latitude="37.986428",
      longitude="-101.751732",
      city="Syracuse",
      state="KS",
      county="Hamilton">
=end

class RandomUsCity

  DATA_FIELDS = [:zip, :latitude, :longitude, :city, :state, :county]
  City = Struct.new(*DATA_FIELDS)

  def initialize
    # read in our city data...
    @cities = []

    data_file = File.join(path_to_resources, "cities.csv")
    CSV.foreach(data_file, :headers => true) do |row|
      @cities << City.new(*(
           row.map do |r|
             if r[0] == 'longitude' || r[0] == 'latitude'
               r[1].to_f
             else
               r[1]
             end
           end
      ))
    end
  end

  ##
  # Returns a struct containing data for a random US city.
  def random_city
    return @cities.sample
  end

  private
  def path_to_resources
    File.join(File.dirname(File.expand_path(__FILE__)), '../data')
  end
end
